<?php

namespace Test\Test\Policies;

use Litepie\User\Contracts\UserPolicy;
use Test\Test\Models\KEY;

class KEYPolicy
{

    /**
     * Determine if the given user can view the k_e_y.
     *
     * @param UserPolicy $user
     * @param KEY $k_e_y
     *
     * @return bool
     */
    public function view(UserPolicy $user, KEY $k_e_y)
    {
        if ($user->canDo('test.k_e_y.view') && $user->isAdmin()) {
            return true;
        }

        return $k_e_y->user_id == user_id() && $k_e_y->user_type == user_type();
    }

    /**
     * Determine if the given user can create a k_e_y.
     *
     * @param UserPolicy $user
     * @param KEY $k_e_y
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('test.k_e_y.create');
    }

    /**
     * Determine if the given user can update the given k_e_y.
     *
     * @param UserPolicy $user
     * @param KEY $k_e_y
     *
     * @return bool
     */
    public function update(UserPolicy $user, KEY $k_e_y)
    {
        if ($user->canDo('test.k_e_y.edit') && $user->isAdmin()) {
            return true;
        }

        return $k_e_y->user_id == user_id() && $k_e_y->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given k_e_y.
     *
     * @param UserPolicy $user
     * @param KEY $k_e_y
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, KEY $k_e_y)
    {
        return $k_e_y->user_id == user_id() && $k_e_y->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given k_e_y.
     *
     * @param UserPolicy $user
     * @param KEY $k_e_y
     *
     * @return bool
     */
    public function verify(UserPolicy $user, KEY $k_e_y)
    {
        if ($user->canDo('test.k_e_y.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given k_e_y.
     *
     * @param UserPolicy $user
     * @param KEY $k_e_y
     *
     * @return bool
     */
    public function approve(UserPolicy $user, KEY $k_e_y)
    {
        if ($user->canDo('test.k_e_y.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
